@@ -14,11 +14,11 @@ use Mojo::JSON;
 use Data::Dumper;
 
 # ABSTRACT: ReRe application
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 plugin 'basic_auth';
 
-my $rere         = ReRe->new;
+my $rere = ReRe->new;
 
 sub error_config_users {
     say "I don't find /etc/rere/users.conf";
@@ -34,7 +34,7 @@ sub error_server_ping {
 
 sub main {
     my $self = shift;
-    &error_config_users unless -r $rere->config_user();
+    &error_config_users unless -r $rere->config_users();
     $rere->start;
     try {
         $rere->server->execute('ping');
@@ -74,6 +74,8 @@ any '/redis/:method/:var/:value/:extra' => {
     my $var      = $self->stash('var') || $self->param('var');
     my $value    = $self->stash('value') || $self->param('value');
     my $extra    = $self->stash('extra') || $self->param('extra');
+    my $callback = $self->param('callback') || '';
+
     my $username = $self->session('name') || '';
 
     $username = $rere->user->auth_ip( $self->tx->remote_address )
@@ -88,42 +90,52 @@ any '/redis/:method/:var/:value/:extra' => {
               }
           );
 
-    $self->render_json(
-        $rere->process( $method, $var, $value, $extra, $username ) );
+    my $json = Mojo::JSON->new;
+    my $output = $json->encode( $rere->process( $method, $var, $value, $extra, $username ) );
+
+    # JSONP
+    $output = "$callback($output)" if $callback;
+    $self->render_text( $output );
 
   } => 'redis';
 
-websocket '/ws' => sub {
-    my $self = shift;
+if ( $rere->websocket->active ) {
 
-    my $username = 'userrw';
+    websocket '/ws' => sub {
+        my $self = shift;
 
-#    my $username = $rere->user->auth_ip( $self->tx->remote_address );
-#
-#    return $self->render_json( { err => 'no_auth' } )
-#      unless $username
-#          or $self->basic_auth(
-#              realm => sub {
-#                  my ( $http_username, $http_password ) = @_;
-#                  $rere->user->auth( $http_username, $http_password );
-#              }
-#          );
-    app->log->debug(sprintf 'Client connected: %s', $self->tx->remote_address);
+        my $username = 'userrw';
 
-    $self->on_message(
-        sub {
-            my ( $self, $message ) = @_;
-            my ( $method, $var, $value, $extra ) = split( ' ', $message );
-            my $ret = $rere->process( $method, $var, $value, $extra, $username );
-            $self->send_message(
-                defined($ret->{$method}) ? $ret->{$method} :
-                    ( defined($ret->{err}) ? $ret->{err} : () )
-            );
-            $self->finish;
-        }
-    );
+        #    my $username = $rere->user->auth_ip( $self->tx->remote_address );
+        #
+        #    return $self->render_json( { err => 'no_auth' } )
+        #      unless $username
+        #          or $self->basic_auth(
+        #              realm => sub {
+        #                  my ( $http_username, $http_password ) = @_;
+        #                  $rere->user->auth( $http_username, $http_password );
+        #              }
+        #          );
+        app->log->debug( sprintf 'Client connected: %s',
+            $self->tx->remote_address );
 
-};
+        $self->on_message(
+            sub {
+                my ( $self, $message ) = @_;
+                my ( $method, $var, $value, $extra ) = split( ' ', $message );
+                my $ret =
+                  $rere->process( $method, $var, $value, $extra, $username );
+                $self->send_message(
+                    defined( $ret->{$method} )
+                    ? $ret->{$method}
+                    : ( defined( $ret->{err} ) ? $ret->{err} : () )
+                );
+                $self->finish;
+            }
+        );
+
+    };
+}
 
 any '/' => sub {
     my $self = shift;
@@ -141,7 +153,7 @@ ReRe::App - ReRe application
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 AUTHOR
 
