@@ -6,7 +6,7 @@ use Redis;
 use ReRe::Config;
 use ReRe::Hook;
 
-our $VERSION = '0.016'; # VERSION
+our $VERSION = '0.017'; # VERSION
 
 has file => (
     is  => 'rw',
@@ -18,13 +18,7 @@ around 'file' => sub {
     my $self = shift;
     return $self->$orig() unless @_;
     my ($file) = shift;
-    my $config = ReRe::Config->new( { file => $file } );
-    my %parse = $config->parse;
-    $self->host( $parse{server}{host} ) if defined( $parse{server}{host} );
-    $self->port( $parse{server}{port} ) if defined( $parse{server}{port} );
-
-    map { $self->add_hook($_) } split( ' ', $parse{server}{hooks} )
-      if defined( $parse{server}{hooks} );
+    $self->_builder_file( ReRe::Config->new( { file => $file } ) );
 };
 
 has host => (
@@ -39,6 +33,13 @@ has port => (
     default => '6379'
 );
 
+has password => (
+    is        => 'rw',
+    isa       => 'Str',
+    default   => '',
+    predicate => 'has_password'
+);
+
 has conn => (
     is      => 'rw',
     isa     => 'Object',
@@ -63,21 +64,34 @@ sub _builder_conn {
     return Redis->new( server => $host );
 }
 
+sub _builder_file {
+    my ( $self, $config ) = @_;
+    my %parse = $config->parse;
+    $self->$_( $parse{server}{$_} ) for grep { defined( $parse{server}{$_} ) } qw(host port admin);
+
+    map { $self->add_hook($_) } split( ' ', $parse{server}{hooks} )
+        if defined( $parse{server}{hooks} );
+}
+
 
 sub execute {
     my $self = shift;
     my $method = shift or return '';
     foreach my $hook ( $self->all_hooks ) {
+        my $ret;
         eval {
-            my $class =
-              ReRe::Hook->with_traits( '+ReRe::Role::Hook', $hook )
-              ->new( method => $method, args => [ @_ ], conn => $self->conn  );
-            $class->process;
+            my $class
+                = ReRe::Hook->with_traits( '+ReRe::Role::Hook', $hook )
+                ->new( method => $method, args => [@_], conn => $self->conn );
+            $ret = $class->process;
         };
         warn $@ if $@;
+        return $ret if $ret;
     }
+    $self->conn->auth( $self->password ) if $self->has_password;
 
-    return @_ ? $self->conn->$method(@_) : $self->conn->$method;
+    my @args = grep {!/^$/} @_;
+    return @args ? $self->conn->$method(@args) : $self->conn->$method;
 }
 
 1;
@@ -92,7 +106,7 @@ ReRe::Server
 
 =head1 VERSION
 
-version 0.016
+version 0.017
 
 =head1 METHODS
 
